  INTERFACE
     SUBROUTINE ADV3NT(S,XT,YT,ZT,SS)
     IMPLICIT NONE
     REAL,      INTENT(IN)    :: s(:,:,:)        ! field for interpolation
     REAL,      INTENT(IN)    :: xt,yt,zt        ! position of interpolated value
     REAL,      INTENT(OUT)   :: ss              ! value of S at x1,y1,z1
     END SUBROUTINE adv3nt

     SUBROUTINE ADVIEC(K1,K2,DELM,JET,DT,TRAJ,TAVG,BACK,CS,PA)
     IMPLICIT NONE
     INTEGER, INTENT(IN)    :: k1,k2           ! last and next time index    
     INTEGER, INTENT(IN)    :: delm            ! seconds between winds 1 and 2
     INTEGER, INTENT(IN)    :: jet             ! current elapsed time (sec)
     INTEGER, INTENT(IN)    :: dt              ! integration step (sec)
     LOGICAL, INTENT(IN)    :: traj            ! flag to turn off dispersion
     LOGICAL, INTENT(IN)    :: tavg            ! time averaged meteorology  
     LOGICAL, INTENT(IN)    :: back            ! integration direction
     REAL,    INTENT(INOUT) :: cs(:,:,:)       ! concentration summation
     REAL,    INTENT(INOUT) :: pa(:)           ! particle array     
     END SUBROUTINE adviec

     SUBROUTINE CONOUT(junit,datebgn,dateend,gbase,cfactor,cs)
     IMPLICIT NONE
     INTEGER(4), INTENT(IN) :: junit
     INTEGER(4), INTENT(IN) :: datebgn(6)
     INTEGER(4), INTENT(IN) :: dateend(6)               
     REAL,       INTENT(IN) :: gbase(9)  
     REAL,       INTENT(IN) :: cfactor
     REAL,       INTENT(IN) :: cs(:,:,:)   
     END SUBROUTINE conout

     SUBROUTINE CONSET (junit,olat,olon,olvl,datemet,datecal,confile)
     IMPLICIT NONE
     INTEGER,       INTENT(IN) :: junit
     REAL,          INTENT(IN) :: olat       ! pollutant source latitude
     REAL,          INTENT(IN) :: olon       ! pollutant source longitude
     REAL,          INTENT(IN) :: olvl       ! pollutant source height
     INTEGER,       INTENT(IN) :: datemet(6) ! meteo data start (yymmddhhmmff)
     INTEGER,       INTENT(IN) :: datecal(6) ! calculation start (yymmddhhmmff)
     CHARACTER(256),INTENT(IN) :: confile 
     END SUBROUTINE conset

     SUBROUTINE DATOUT (junit,cfactor,olat,olon,stnfile)
     IMPLICIT NONE
     INTEGER,        INTENT(IN) :: junit
     REAL,           INTENT(IN) :: cfactor  
     REAL,           INTENT(IN) :: olat,olon
     CHARACTER(256), INTENT(IN) :: stnfile
     END SUBROUTINE datout

     SUBROUTINE DATSET (junit,gbase,datfile,century)
     IMPLICIT NONE
     INTEGER,        INTENT(IN) :: junit
     REAL,           INTENT(IN) :: gbase(9)
     CHARACTER(256), INTENT(IN) :: datfile
     INTEGER,        INTENT(OUT):: century
     END SUBROUTINE datset

     SUBROUTINE DATSUM(datecal,cs)
     IMPLICIT NONE
     INTEGER(4), INTENT(IN) :: datecal(6)           
     REAL,       INTENT(IN) :: cs(:,:,:)   
     END SUBROUTINE datsum

     SUBROUTINE EMTPAR (NUMPAR,PAREMT,DELM,K1,K2,TF,PMASSV,X0,Y0,Z0,ZF,PA)
     IMPLICIT none
     INTEGER, INTENT(IN) :: numpar    ! current number of active particles
     INTEGER, INTENT(IN) :: paremt    ! number of particles to emit
     INTEGER, INTENT(IN) :: delm      ! time (s) between meteorology
     INTEGER, INTENT(IN) :: k1,k2     ! meteorological data time indicies
     REAL,    INTENT(IN) :: tf        ! time interpolation factor
     REAL,    INTENT(IN) :: pmassv    ! individual particle mass value
     REAL,    INTENT(IN) :: x0,y0,z0  ! particle position
     REAL,    INTENT(IN) :: zf        ! vertical index position
     REAL, INTENT(INOUT) :: pa(:,:)   ! particle array
     END SUBROUTINE emtpar

     SUBROUTINE METCNV(tked,ii,jj,kt,tker,ptop,sg)
     IMPLICIT NONE
     LOGICAL, INTENT(IN)    :: tked     ! tke field in meteorology
     INTEGER, INTENT(IN)    :: ii,jj    ! horizontal index
     INTEGER, INTENT(IN)    :: kt       ! number of active time
     REAL,    INTENT(IN)    :: tker     ! ratio of vert to horiz turb
     REAL,    INTENT(IN)    :: ptop     ! top pressure for hydrostatic
     REAL,    INTENT(IN)    :: sg(:)    ! hydrostatic pressure levels  
     END SUBROUTINE metcnv

     SUBROUTINE METLVL(KUNIT,KT,KREC,NVLVL,TAVG)
     IMPLICIT NONE
     INTEGER,      INTENT(IN)    :: kunit     ! input device unit number
     INTEGER,      INTENT(IN)    :: kt        ! number of active time
     INTEGER,      INTENT(IN)    :: krec      ! record number of index record
     INTEGER,      INTENT(IN)    :: nvlvl     ! number of variables per level
     LOGICAL,      INTENT(IN)    :: tavg      ! flag for time averaged data
     END SUBROUTINE metlvl

     SUBROUTINE METSFC(KUNIT,KT,KREC,NVSFC)
     IMPLICIT NONE
     INTEGER,      INTENT(IN)    :: kunit     ! input device unit number
     INTEGER,      INTENT(IN)    :: kt        ! number of active time
     INTEGER,      INTENT(IN)    :: krec      ! record number of index record
     INTEGER,      INTENT(IN)    :: nvsfc     ! number of variables per level
     END SUBROUTINE metsfc

     SUBROUTINE METSET (kunit,metfile,traj,tavg,tked,nxp,nyp,nzp,nvsfc,  &
                        nvlvl,numper,numndx,delm,ptop,sg)   
     IMPLICIT none
     CHARACTER(256), INTENT(IN) :: metfile(:)
     INTEGER, INTENT(IN)        :: kunit
     LOGICAL, INTENT(IN)        :: traj         ! flag for trajectories
     LOGICAL, INTENT(OUT)       :: tavg         ! flag for time averaged data
     LOGICAL, INTENT(OUT)       :: tked         ! tke field in meteorology   
     INTEGER, INTENT(OUT)       :: nxp,nyp,nzp  ! meteo grid dimensions
     INTEGER, INTENT(OUT)       :: nvsfc,nvlvl  ! numb variables at sfc, aloft
     INTEGER, INTENT(OUT)       :: numper       ! numb records per time
     INTEGER, INTENT(OUT)       :: numndx       ! numb of index records  
     INTEGER, INTENT(OUT)       :: delm         ! time between meteorology (s)
     REAL,    INTENT(OUT)       :: ptop         ! hydrostatic pressure top    
     REAL,    INTENT(OUT)       :: sg(:)        ! hydrostatic sigma levels    
     END SUBROUTINE metset

     SUBROUTINE METPRJ  (kunit,diag,gbase,datemet)
     IMPLICIT none
     INTEGER, INTENT(IN)  :: kunit      ! meteorological unit number
     LOGICAL, INTENT(IN)  :: diag       ! diagnostic output
     REAL,    INTENT(OUT) :: gbase(9)   ! array that defines grid conversions
     INTEGER, INTENT(OUT) :: datemet(6) ! start day and hour
     END SUBROUTINE metprj

     SUBROUTINE METGRD (ii,jj)
     IMPLICIT none
     INTEGER, INTENT(IN) :: ii,jj ! option to use local rather than average
     END SUBROUTINE metgrd

     SUBROUTINE METPRT (ii,jj,kt)
     IMPLICIT none
     INTEGER, INTENT(IN) :: ii,jj,kt
     END SUBROUTINE metprt

     SUBROUTINE PARDSP(k1,k2,tf,np,dt,nrand,delh,xpos,ypos,zpos, &
                       uprime,vprime,wprime,wratio)
     IMPLICIT NONE
     INTEGER,      INTENT(IN)     :: k1,k2       ! time index (previous and next)
     REAL,         INTENT(IN)     :: tf          ! time interpolation factor
     INTEGER,      INTENT(IN)     :: dt          ! advection time step (sec)
     INTEGER,      INTENT(IN)     :: np          ! sequential particle number
     INTEGER,      INTENT(IN)     :: nrand       ! index pointer for random number
     REAL,         INTENT(IN)     :: delh        ! vertical cell spacing (m)
     REAL,         INTENT(IN)     :: xpos        ! EW horizontal particle position
     REAL,         INTENT(IN)     :: ypos        ! NS horizontal particle position
     REAL,         INTENT(IN)     :: zpos        ! vertical particle position
     REAL,         INTENT(INOUT)  :: uprime      ! u' turbulent velocity (x)
     REAL,         INTENT(INOUT)  :: vprime      ! v' turbulent velocity (y)
     REAL,         INTENT(INOUT)  :: wprime      ! w' turbulent velocity (z)
     REAL,         INTENT(INOUT)  :: wratio      ! w'/sigw
     END SUBROUTINE pardsp

     SUBROUTINE SVGOUT(junit,kunit,svgfile,mapfile,datebgn,dateend, &
                       thin,x0,y0,gbase,cfactor,cs)
     IMPLICIT NONE
     INTEGER, INTENT(IN) :: junit,kunit
     CHARACTER(256),INTENT(IN) :: svgfile 
     CHARACTER(256),INTENT(IN) :: mapfile 
     INTEGER, INTENT(IN) :: datebgn(6)
     INTEGER, INTENT(IN) :: dateend(6)
     LOGICAL, INTENT(IN) :: thin
     REAL,    INTENT(IN) :: x0,y0       
     REAL,    INTENT(IN) :: gbase(9)
     REAL,    INTENT(IN) :: cfactor
     REAL,    INTENT(IN) :: cs(:,:,:)
     END SUBROUTINE svgout

     SUBROUTINE TRJDSK(JUNIT,DATEMET,HOURS,TLAT,TLON,TZHT,TMETV)
     IMPLICIT NONE
     INTEGER,  INTENT(IN) :: junit         ! output file unit number       
     INTEGER,  INTENT(IN) :: datemet(6)    ! trajectory date and time
     REAL,     INTENT(IN) :: hours         ! trajectory age from start
     REAL,     INTENT(IN) :: tlat,tlon     ! trajectory position   
     REAL,     INTENT(IN) :: tzht          ! trajectory height AGL
     REAL,     INTENT(IN) :: tmetv         ! trajectory diagnostic variable
     END SUBROUTINE trjdsk

     SUBROUTINE TRJSET(junit,back,olat,olon,olvl,datemet,datecal,trjfile)
     IMPLICIT NONE
     INTEGER, INTENT(IN) :: junit
     LOGICAL, INTENT(IN) :: back       ! flag to indicate direction
     REAL,    INTENT(IN) :: olat       ! pollutant source latitude
     REAL,    INTENT(IN) :: olon       ! pollutant source longitude
     REAL,    INTENT(IN) :: olvl       ! pollutant source height
     INTEGER, INTENT(IN) :: datemet(6) ! meteorological data start (yymmddhhmmff)
     INTEGER, INTENT(IN) :: datecal(6) ! calculation start (yymmddhhmmff)
     CHARACTER(256), INTENT(IN) :: trjfile
     END SUBROUTINE trjset
  END INTERFACE
