!----------------------------------------------------------------------
! linear interpolation routine for three dimensional variables
!----------------------------------------------------------------------
! Last Revised: 09 Dec 2019
!               08 Aug 2020 - updated common block
!----------------------------------------------------------------------

SUBROUTINE ADV3NT(S,X1,Y1,Z1,SS)

  IMPLICIT NONE

!----------------------------------------
! argument list variables

  REAL,      INTENT(IN)    :: s(:,:,:)      ! field for interpolation
  REAL,      INTENT(IN)    :: x1,y1,z1      ! position of interpolated value
  REAL,      INTENT(OUT)   :: ss            ! value of S at x1,y1,z1

!----------------------------------------
! internal variables

  INTEGER   :: i1,j1,k1, i1p,j1p,k1p 
  REAL      :: xf,yf,zf, sb,st,sh 

!----------------------------------------

  INTEGER   :: nxp,nyp,nzp   ! grid limits
  INTEGER   :: kzmax         ! model top (m)  
  INTEGER   :: cgratio       ! number of concentration grid cells to WRF cells

  COMMON /gridpt/ nxp,nyp,nzp,kzmax,cgratio

!----------------------------------------
! grid index: horizontal at cell center point
!             vertical index defined at interfaces
!             and where the index at ground level =1

!#Experimental version for no interpolation
!#returns the value at the nearest point

!#I1=MIN(NINT(X1),NXP)
!#J1=MIN(NINT(Y1),NYP)
!#K1=MIN(NINT(Z1),NZP)
!#SS=S(I1,J1,K1)
!#RETURN

! define the lower interpolation index
  I1=INT(X1)
  J1=INT(Y1)
  K1=INT(Z1)

! set upper index
  I1P=MIN(I1+1,NXP)
  J1P=MIN(J1+1,NYP)
  K1P=MIN(K1+1,NZP)

! fractional interpolation factors to x,y,z
  XF=X1-FLOAT(I1)
  YF=Y1-FLOAT(J1)
  ZF=Z1-FLOAT(K1)

! value at x1 along bottom of lowest layer
  SB=(S(I1P,J1 ,K1)-S(I1,J1 ,K1))*XF+S(I1,J1 ,K1)
! value at x1 along top of lowest layer
  ST=(S(I1P,J1P,K1)-S(I1,J1P,K1))*XF+S(I1,J1P,K1)
! value at x1,y1 of lowest layer
  SS=(ST-SB)*YF+SB

! value requested on lower boundary
  IF(ZF.LE.0.0)RETURN

! value at x1 along bottom of upper layer
  SB=(S(I1P,J1 ,K1P)-S(I1,J1 ,K1P))*XF+S(I1,J1, K1P)
! value at x1 along top of upper layer
  ST=(S(I1P,J1P,K1P)-S(I1,J1P,K1P))*XF+S(I1,J1P,K1P)
! value at x1,y1 of upper layer
  SH=(ST-SB)*YF+SB

! value at x1,y1,z1
  SS=(SH-SS)*ZF+SS

END SUBROUTINE adv3nt
