!-------------------------------------------------------------
! Based upon displacement values recompute the time step
!-------------------------------------------------------------
! Last Revised: 02 Nov 2020
!               17 Nov 2020 - split tratio into horiz and vert
!-------------------------------------------------------------

SUBROUTINE ADVDEL(TRATIOV,TRATIOH,DELX,DELY,DELZ,DELT,DT)

  IMPLICIT NONE

  REAL,    INTENT(IN)      :: tratiov,tratioh
  REAL,    INTENT(IN)      :: delx,dely,delz
  INTEGER, INTENT(IN)      :: delt
  INTEGER, INTENT(INOUT)   :: dt
  REAL                     :: delh,delv 

! the maximim grid point displacement can also be viewed as
! the factor by which the time step needs to be reduced to
! make the displacement less than TRATIO

  IF(ABS(DELX).LE.TRATIOH.AND.ABS(DELY).LE.TRATIOH.AND.  &
     ABS(DELZ).LE.TRATIOV) RETURN   

  DELH=TRATIOH*ABS(DELT)/MAX(ABS(DELX),ABS(DELY))
  DELV=TRATIOV*ABS(DELT)/ABS(DELZ)
  DT=MAX( 2, MIN( ABS(DELT),NINT(DELH),NINT(DELV) ) )

  IF(DT.LT.DELT)THEN
!    round down the time step to even multiple of DT
     DO WHILE (MOD(ABS(DELT),DT).NE.0.AND.DT.GT.1)
        DT=DT-1
     END DO
     DT=SIGN(DT,DELT)
  END IF

END SUBROUTINE advdel
