! ----------------------------------------------------------------------------
! Outputs the concentrations in DATEM format based upon the structure of the
! previously read measured data file where the measured values have been 
! replaced by the model calculation. This routine is called once at the end
! of the simulation the output the internal sampler concentration array.
! ----------------------------------------------------------------------------
! Last Revised: 12 Aug 2020
!               08 Dec 2020 - added position information (c2datem -s option)
!               29 Dec 2020 - century assumed in year field; no output missing
!               02 Jan 2021 - variable name for output file
! ----------------------------------------------------------------------------

SUBROUTINE DATOUT (junit,cfactor,olat,olon,stnfile)

  USE datval

  IMPLICIT NONE
 
  INTEGER,        INTENT(IN) :: junit
  REAL,           INTENT(IN) :: cfactor
  REAL,           INTENT(IN) :: olat,olon
  CHARACTER(256), INTENT(IN) :: stnfile
  INTEGER                    :: n

!-----------------------------------------------------
  
  OPEN (JUNIT,FILE=stnfile)

  WRITE(JUNIT,'(2F10.3,2A)') OLAT,OLON,' ',INFO(1)
  WRITE(JUNIT,'(A)') INFO(2)
  DO N=1,NREC                
     CALC(N)=CALC(N)*CFACTOR
     IF(CALC(N).GT.100.0)THEN
        WRITE(JUNIT,'(I4,2I3,2(I3,I2.2),F6.2,F8.2,F8.1,I5)')    &
              JYR(N),JMO(N),JDA(N),JHR(N),JMN(N),LHR(N),LMN(N), &
              SLAT(N),SLON(N),CALC(N),KSTA(N)
     ELSEIF(CALC(N).GT.10.0)THEN
        WRITE(JUNIT,'(I4,2I3,2(I3,I2.2),F6.2,F8.2,F8.2,I5)')    &
              JYR(N),JMO(N),JDA(N),JHR(N),JMN(N),LHR(N),LMN(N), &
              SLAT(N),SLON(N),CALC(N),KSTA(N)
     ELSEIF(CALC(N).GT.1.0)THEN
        WRITE(JUNIT,'(I4,2I3,2(I3,I2.2),F6.2,F8.2,F8.3,I5)')    &
              JYR(N),JMO(N),JDA(N),JHR(N),JMN(N),LHR(N),LMN(N), &
              SLAT(N),SLON(N),CALC(N),KSTA(N)
     ELSEIF(CALC(N).GT.0.0)THEN
        WRITE(JUNIT,'(I4,2I3,2(I3,I2.2),F6.2,F8.2,F8.4,I5)')    &
              JYR(N),JMO(N),JDA(N),JHR(N),JMN(N),LHR(N),LMN(N), &
              SLAT(N),SLON(N),CALC(N),KSTA(N)
     ELSEIF(CALC(N).EQ.0.0)THEN
        WRITE(JUNIT,'(I4,2I3,2(I3,I2.2),F6.2,F8.2,F8.1,I5)')    &
              JYR(N),JMO(N),JDA(N),JHR(N),JMN(N),LHR(N),LMN(N), &
              SLAT(N),SLON(N),CALC(N),KSTA(N)
     ELSE
!       missing data when calc = (-1 x cfactor)
        CALC(N)=-1.0
!##     WRITE(JUNIT,'(I4,2I3,2(I3,I2.2),F6.2,F8.2,F8.1,I5)')    &
!##           JYR(N),JMO(N),JDA(N),JHR(N),JMN(N),LHR(N),LMN(N), &
!##           SLAT(N),SLON(N),CALC(N),KSTA(N)
     END IF
  END DO 
  CLOSE (JUNIT)

END SUBROUTINE datout  
