! ----------------------------------------------------------------------------
! Configure the output concentration variables for DATEM format input file
! be reading the locations, start, and stop time of each measurement (data
! record). The actual measurements are replaced by a missing indicator which
! will be replaced during the calculation (datsum) by the model predictions.
! The DATEM file only acts as a template for the final model output.
! ----------------------------------------------------------------------------
! Last Revised: 12 Aug 2020
!               18 Nov 2020 - generalized input
!               28 Dec 2020 - switch back to 4-digit years
! ----------------------------------------------------------------------------

SUBROUTINE DATSET (junit,gbase,datfile,century)

  USE datval

  IMPLICIT NONE
 
  INTEGER,        INTENT(IN) :: junit
  REAL,           INTENT(IN) :: gbase(9)
  CHARACTER(256), INTENT(IN) :: datfile
  INTEGER,        INTENT(OUT):: century

  CHARACTER(80)       :: datarec
  INTEGER             :: n,kret
  INTEGER(KIND=8)     :: csec,psec,julsec 

!-----------------------------------------------------
  
  OPEN (JUNIT,FILE=DATFILE) 
  READ (JUNIT,'(A)') INFO(1)
  READ (JUNIT,'(A)') INFO(2)

  NREC=0
  KRET=0
  DO WHILE (KRET.EQ.0)
     READ(JUNIT,'(A)',IOSTAT=KRET) DATAREC
     IF(KRET.EQ.0) NREC=NREC+1
  END DO 
  REWIND (JUNIT)

  ALLOCATE (XPOS(NREC),YPOS(NREC),STAT=KRET)
  ALLOCATE (SLAT(NREC),SLON(NREC),CALC(NREC),CNTR(NREC),STAT=KRET)
  ALLOCATE (JYR(NREC),JMO(NREC),JDA(NREC),JHR(NREC),JMN(NREC),STAT=KRET)
  ALLOCATE (KYR(NREC),KMO(NREC),KDA(NREC),KHR(NREC),KMN(NREC),STAT=KRET)
  ALLOCATE (LHR(NREC),LMN(NREC),KSTA(NREC),STAT=KRET)

  READ (JUNIT,'(A)')
  READ (JUNIT,'(A)')
  DO N=1,NREC                
     READ(JUNIT,'(A)',IOSTAT=KRET) DATAREC
     READ(DATAREC,'(I4,2I3,2(I3,I2),F6.2,F8.2,F8.1,I5)')     &
          JYR(N),JMO(N),JDA(N),JHR(N),JMN(N),LHR(N),LMN(N),  &
          SLAT(N),SLON(N),CALC(N),KSTA(N)

     IF(n.EQ.1) century=(jyr(n)/100)*100

!    determine index value on WRF grid
     CALL CLL2XY(GBASE,SLAT(N),SLON(N),XPOS(N),YPOS(N))

!    force missing value, zero and positive filled by model results
     CALC(N)=-1.0
     CNTR(N)=-1.0

!    convert sample start to julian seconds
     CSEC=JULSEC(JYR(N),JMO(N),JDA(N),JHR(N),JMN(N),0)
!    add sample duration
     CSEC=CSEC+LHR(N)*3600+LMN(N)*60

!    initially set sample end time (k) to start time (j)
     KYR(N)=JYR(N)
     KMO(N)=JMO(N)
     KDA(N)=JDA(N)
     KHR(N)=JHR(N)
     KMN(N)=JMN(N)

!    add minutes to sample duration
     KMN(N)=KMN(N)+LMN(N)
     IF(KMN(N).GE.60)THEN
        KHR(N)=KHR(N)+1
        KMN(N)=MOD(KMN(N),60)
     END IF

!    add hours to sample duration
     KHR(N)=KHR(N)+LHR(N)
     IF(KHR(N).GE.24)THEN
        KDA(N)=KDA(N)+1
        KHR(N)=MOD(KHR(N),24)

!       check sample end time
        PSEC=JULSEC(KYR(N),KMO(N),KDA(N),KHR(N),KMN(N),0)
        IF(PSEC.NE.CSEC)THEN
           KDA(N)=1
           KMO(N)=KMO(N)+1
           IF(KMO(N).GT.12)THEN
              KMO(N)=1
              KYR(N)=KYR(N)+1
           END IF
        END IF
     END IF

  END DO 
  CLOSE (JUNIT)

END SUBROUTINE datset  
