!-------------------------------------------------------------------------------
! Computes the Julian second given a YYYY MM DD HH MM SS
!                                       I  J  K  L  M  N
! The definition of Julian date is the interval of time in days and fractions 
! of a day, since 4713 BC January 1, Greenwich noon, Julian proleptic calendar
! In this application time starts at midnight rather than noon.
! (credit: http://aa.usno.navy.mil/faq/docs/JD_Formula.php) 
!-------------------------------------------------------------------------------

INTEGER(KIND=8) FUNCTION JULSEC (I,J,K,L,M,N)     
IMPLICIT NONE
INTEGER, INTENT(IN) :: I,J,K,L,M,N            
JULSEC = 86400*(K-32075+                 &
         1461*(I+4800+(J-14)/12)/4+      &
         367*(J-2-(J-14)/12*12)/12-      &
         3*((I+4900+(J-14)/12)/100)/4)+  &
         L*3600+M*60+N
END FUNCTION julsec

!----------------------------------------------------
!PROGRAM test
!  INTEGER(KIND=8) :: JULSEC, JSEC, JSEC0
!  DO K=1950,2100
!  JSEC0=JULSEC(K,1,1,0,0,0)
!  DO I=1,12
!  DO J=1,31
!     JSEC=JULSEC(K,I,J,0,0,0)-JSEC0
!     write(*,*)k,i,j,jsec/86400,jsec
!  END DO
!  END DO
!  END DO
!END PROGRAM test
!include 'julsec.f'
