!-----------------------------------------------------------------------------
! Plot map boundaries on the display grid
! Last Revised: 31 Jan 2021
!               24 Feb 2021 - read old format ARLMAP
!-----------------------------------------------------------------------------

SUBROUTINE MAPBDY(junit,kunit,imin,jmin,imax,jmax, &
                  pxmin,pymin,pxmax,pymax,cgratio,gbase)

  IMPLICIT none

  INTEGER, INTENT(IN) :: junit,kunit
  INTEGER, INTENT(IN) :: imin,jmin,imax,jmax
  INTEGER, INTENT(IN) :: pxmin,pymin,pxmax,pymax
  INTEGER, INTENT(IN) :: cgratio  
  REAL,    INTENT(IN) :: gbase(9)

  CHARACTER(20)     :: LABEL
  LOGICAL           :: CLIP
  INTEGER           :: KLINE,KPTS,KTYPE,KSIG
  INTEGER           :: MPTS,KRET,IJ,K
  REAL              :: X,Y,XS,YS,WX,WY

  REAL, ALLOCATABLE :: PLAT(:),PLON(:)

  MPTS=500  ! map background vector array
  ALLOCATE (PLAT(MPTS),PLON(MPTS))

  ij=MAX(imax-imin,jmax-jmin)
  wx=(pxmax-pxmin)/float(ij)
  wy=(pymax-pymin)/float(ij)

!-----------------------------------------------------
! read vectors and draw lines

  KRET=0
vector : DO WHILE (KRET.EQ.0)
     READ(KUNIT,'(A)',IOSTAT=KRET)LABEL
     IF(KRET.NE.0) CYCLE vector

     READ(LABEL,'(4I5)',IOSTAT=KRET)KLINE,KPTS,KTYPE,KSIG
     IF(KRET.EQ.0)THEN
        KTYPE=MAX(1,KTYPE)
        KSIG =MAX(1,KSIG) 
     ELSE
!       for undefined older format ARLMAP files
        KTYPE=2
        KSIG=2
     END IF

     IF(KPTS.GT.MPTS)THEN
        DEALLOCATE (PLAT,PLON)
        MPTS=MPTS+500
        ALLOCATE (PLAT(MPTS),PLON(MPTS))
     END IF

     SELECT CASE (ksig)
     CASE (1)
       READ(KUNIT,'(10F6.1)')(PLAT(K),K=1,KPTS)
       READ(KUNIT,'(10F7.1)')(PLON(K),K=1,KPTS)
     CASE (2)
       READ(KUNIT,'(10F6.2)')(PLAT(K),K=1,KPTS)
       READ(KUNIT,'(10F7.2)')(PLON(K),K=1,KPTS)
     CASE (3)
       READ(KUNIT,'(10F7.3)')(PLAT(K),K=1,KPTS)
       READ(KUNIT,'(10F8.3)')(PLON(K),K=1,KPTS)
     CASE (4)
       READ(KUNIT,'(10F8.4)')(PLAT(K),K=1,KPTS)
       READ(KUNIT,'(10F9.4)')(PLON(K),K=1,KPTS)
     END SELECT
     IF(KPTS.LE.1) CYCLE vector

!    check if any point along the vector is in the clip region
!    and convert to concentration grid units
     CLIP=.FALSE.
     DO K=1,KPTS
        CALL CLL2XY(gbase,plat(k),plon(k),x,y)
!       meteo to concentration grid
           xs=1.0+cgratio*(x-1.0)
           ys=1.0+cgratio*(y-1.0)
!       concentration grid to display grid
           x = (xs-imin)*wy + pxmin
           y = pymax - (ys-jmin)*wx
        IF(INT(x).GE.pxmin.AND.NINT(x).LE.pxmax.AND.   &
           INT(y).GE.pymin.AND.NINT(y).LE.pymax) CLIP=.TRUE.
!       replace lat-lon vector with display units
           plat(k)=y
           plon(k)=x
     END DO 

!    complete curve if anything in array
     IF(CLIP)THEN
        WRITE(JUNIT,'(A,F6.1,A,F6.1,A,F6.1,A)')  &
          '<polyline points = "' 
        DO K=1,KPTS
           WRITE(JUNIT,'(2(F6.1,A))') plon(k),',',plat(k),' '
        END DO 
        SELECT CASE (ktype)
        CASE (1) ! national
           WRITE(JUNIT,'(2A)')'" fill="none" stroke="darkblue" ',  &
                              ' stroke-width="1.0" />' 
        CASE (2) ! states 
           WRITE(JUNIT,'(2A)')'" fill="none" stroke="mediumblue" ',  &
                              ' stroke-width="0.8" />' 
        CASE (3) ! counties
           WRITE(JUNIT,'(2A)')'" fill="none" stroke="skyblue" ',  &
                              ' stroke-width="0.6" />' 
        CASE (4) ! roads
           WRITE(JUNIT,'(2A)')'" fill="none" stroke="tan" ',  &
                              ' stroke-width="0.5" />' 
        END SELECT
     END IF   

  END DO vector 
END SUBROUTINE mapbdy
