!----------------------------------------------------------------------------
! Diagnostic subroutine to print the meteorolgoical profile
!----------------------------------------------------------------------------
! Last Revised: 19 Nov 2020
!----------------------------------------------------------------------------

SUBROUTINE METPRT (ii,jj,kt)

  USE metval

  IMPLICIT none

  INTEGER, INTENT(IN) :: ii,jj,kt
  INTEGER             :: kz
  INTEGER             :: nxp,nyp,nzp,kzmax,cgratio

  COMMON /gridpt/ nxp,nyp,nzp,kzmax,cgratio

  WRITE(*,*)      
  WRITE(*,'(3x,a6,1x,2a4,2a5,6a6)')  &
        'Z','P','T','Q','E','U','V','W','Su','Sv','Sw'
  WRITE(*,'(3x,a6,1x,2a4,2a5,6a6)')  &
        'm','mb','oK','g/kg','J/kg','m/s','m/s','cm/s','m/s','m/s','m/s'

  DO kz=nzp,1,-1
     IF(kz.LT.nzp.AND.kz.GT.1)THEN
!       mark the PBL depth in the profile
        IF(zi(ii,jj,kt).GE.zt(kz).and.zi(ii,jj,kt).LT.zt(kz+1)) & 
           WRITE(*,'(3X,F8.2)') zi(ii,jj,kt)
     END IF

     WRITE(*,'(I3,I6,1X,2I4,2F5.2,6F6.2)') kz,                                 &
        NINT(zt(      kz)),       NINT(p(ii,jj,kz,kt)),                        &
        NINT( t(ii,jj,kz,kt)),  1000.0*q(ii,jj,kz,kt),         e(ii,jj,kz,kt), &
              u(ii,jj,kz,kt),          v(ii,jj,kz,kt),   100.0*w(ii,jj,kz,kt), &
             uu(ii,jj,kz,kt),         vv(ii,jj,kz,kt),        ww(ii,jj,kz,kt)
  END DO
  WRITE(*,*)'Terrain: ',ABS(hh(ii,jj,1)),'     at i,j: ',ii,jj
  WRITE(*,*)' '

END SUBROUTINE metprt
