SUBROUTINE PAKINP(RVAR,CVAR,PREC,NEXP,VAR1)

  IMPLICIT NONE

!-------------------------------------------------------------------------------
! argument list variables
!-------------------------------------------------------------------------------
! Last Revised: 09 Dec 2019
!               08 Aug 2020 - updated common block
!-------------------------------------------------------------------------------

  REAL,          INTENT(OUT)   :: rvar (:,:)     ! real data unpacked
  CHARACTER(1),  INTENT(IN)    :: cvar (:)       ! packed input of NX*NY
  REAL,          INTENT(IN)    :: prec           ! precision of packed data 
  INTEGER,       INTENT(IN)    :: nexp           ! packing scaling exponent
  REAL,          INTENT(IN)    :: var1           ! value of array at (1,1)

!-------------------------------------------------------------------------------
! internal variable definitions
!-------------------------------------------------------------------------------

  REAL           :: scexp,rold,rnew,rini
  INTEGER        :: i,j,k

  INTEGER        :: nxp,nyp,nzp
  INTEGER        :: kzmax         ! model top (m)
  INTEGER        :: cgratio       ! number of concentration grid cells to WRF cells

  COMMON /gridpt/ nxp,nyp,nzp,kzmax,cgratio

!-------------------------------------------------------------------------------
! Some Fortran compilers the ICHAR function is undefined for values greater 128
! Generic Fortran and C code functions for conversions can be used (ncep mova2i)
! In Fortran:  JCHAR=ISHFT(TRANSFER(MYCHR,JCHAR),8-BIT_SIZE(JCHAR))
! In C:        INT MOVA2I(UNSIGNED CHAR *A) { RETURN (INT) (*A); }
! If ICHAR always returns a signed integer, then ICHAR can be replaced with:
!-------------------------------------------------------------------------------
  CHARACTER(1)  :: mychr    
  INTEGER       :: jchar
  JCHAR(MYCHR)=IAND(ICHAR(MYCHR),255)
!-------------------------------------------------------------------------------

  SCEXP= 1.0 / 2.0**(7-NEXP)  ! scaling exponent

  ROLD=VAR1
  DO J=1,NYP
     DO I=1,NXP          
        K=(J-1)*NXP+I
        RNEW=(FLOAT(JCHAR(CVAR(K))-127)*SCEXP)+ROLD
        ROLD=RNEW
        IF(I.EQ.1)RINI=RNEW ! save 1st column value to start next row
        IF(ABS(RNEW).LT.PREC) RNEW=0.0
        RVAR(I,J)=RNEW
     END DO
     ROLD=RINI
  END DO
 
END SUBROUTINE pakinp
