!-------------------------------------------------------------------------------
! Configure the trajectory output file
!-------------------------------------------------------------------------------
! Last Revised: 29 Oct 2020
!               28 Dec 2020 - adjusted output for century in date
!               02 Jan 2021 - output file name
!-------------------------------------------------------------------------------

SUBROUTINE TRJSET(junit,back,olat,olon,olvl,datemet,datecal,trjfile) 

  IMPLICIT NONE

  INTEGER, INTENT(IN) :: junit 
  LOGICAL, INTENT(IN) :: back       ! flag to indicate direction
  REAL,    INTENT(IN) :: olat       ! pollutant source latitude
  REAL,    INTENT(IN) :: olon       ! pollutant source longitude
  REAL,    INTENT(IN) :: olvl       ! pollutant source height
  INTEGER, INTENT(IN) :: datemet(6) ! meteorological data start (yymmddhhmmff)
  INTEGER, INTENT(IN) :: datecal(6) ! calculation start (yymmddhhmmff)
  CHARACTER(256), INTENT(IN) :: trjfile

  INTEGER, PARAMETER :: tfmt = 1    ! trajectory file format
  INTEGER, PARAMETER :: kmet = 1    ! number of meteo files
  INTEGER, PARAMETER :: nloc = 1    ! number of start locations
  INTEGER, PARAMETER :: ndia = 1    ! number of output diagnostics

  CHARACTER(8)       :: dirctn(2), motion(0:5), metout(2)

  CHARACTER(4)       :: model_id    ! meteorological model identification
  REAL               :: gsize       ! meteorology grid size
  REAL               :: blat,blon   ! bottom lower left corner
  REAL               :: tlat,tlon   ! top upper right corner
  INTEGER            :: yy          ! two digit year

  COMMON /wrfgrd/ model_id,gsize,blat,blon,tlat,tlon

!-----------------------------------------------
  DATA dirctn /'FORWARD','BACKWARD'/
  DATA motion /'OMEGA','ISOBARIC','THETA','DENSITY','ISOSIGMA','NOTSET'/  
  DATA metout /'PRESSURE','TERR_MSL'/
!-----------------------------------------------

  OPEN(JUNIT,FILE=trjfile)              

! meteo file information index records
  yy=datemet(1)-(datemet(1)/100)*100
  WRITE(JUNIT,'(2I6)')   KMET,TFMT
  WRITE(JUNIT,'(A8,5I6)')model_id,yy,datemet(2:4),datemet(6)

! trajectory information index records
  IF(BACK)THEN
     WRITE(JUNIT,'(I6,2(1X,A8))')NLOC,DIRCTN(2),MOTION(1)
  ELSE
     WRITE(JUNIT,'(I6,2(1X,A8))')NLOC,DIRCTN(1),MOTION(1)
  END IF

! starting location
  yy=datecal(1)-(datecal(1)/100)*100
  WRITE(JUNIT,'(4I6,2F9.3,F8.1)') yy,datecal(2:4),olat,olon,olvl

! additional diagnostic meteorological information
  WRITE(JUNIT,'(I6,10(1X,A8))')NDIA,METOUT(1) 

END SUBROUTINE trjset
